@@ -2,13 +2,15 @@
 # -*- coding: utf-8 -*-
 #
 #  terminal.py
-"""Useful functions for terminal-based programs"""
+"""
+Useful functions for terminal-based programs
+"""
 #
-#  Copyright 2014-2019 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2014-2019 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  get_terminal_size, _get_terminal_size_windows, _get_terminal_size_tput and _get_terminal_size_linux
-#		from https://gist.github.com/jtriley/1108174
-#  		Copyright 2011 jtriley
+# 		from https://gist.github.com/jtriley/1108174
+#  		Copyright © 2011 jtriley
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU Lesser General Public License as published by
@@ -27,13 +29,16 @@
 #
 #
 
+# stdlib
 import os
 import sys
 import shlex
 import struct
 import platform
 import subprocess
-from .__init__ import pyversion
+
+# this package
+from domdf_python_tools import pyversion
 
 
 def clear():
@@ -55,6 +60,7 @@ def br():
 	
 	print("")
 
+
 def entry(text_to_print):
 	"""
 	Version-agnostic input function
@@ -195,6 +201,7 @@ def _get_terminal_size_linux():
 			return None
 	return int(cr[1]), int(cr[0])
 
+
 if __name__ == "__main__":
 	sizex, sizey = get_terminal_size()
 	print('width =', sizex, 'height =', sizey)
